#!/bin/sh

# Process this file with autoconf to produce a configure script.

# Copyright (C) 2012 Henrik Sandklef
#
# This file is part of Searduino
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

export PATH=/opt/searduino/bin:${PATH}
export LD_LIBRARY_PATH=/opt/searduino/lib
export PYTHONPATH=/opt/searduino/lib

/opt/searduino/bin/pardon.py $*

